import os
from pprint import pprint

import click
import yaml

from splitem.lib import read_target


@click.command()
@click.argument("target")
@click.option("--ext", default='yml', type=str, help='YAML extension to append to output files [Default: yml]')
@click.option("--out-dir", default='', type=str, help='Output directory for generated files. [Default: "./"]')
def run(target, ext, out_dir):
    """Parse a target manifest and extract individual manifests into separate files."""
    manifests = read_target(target)
    out_dir = os.path.abspath(out_dir)
    for manifest in manifests:
        file_name = manifest['metadata']['name'].lower()
        file_desc = manifest['kind'].lower()
        full_file = "{}/{}-{}.{}".format(out_dir, file_desc, file_name, ext)
        print("writing {}".format(full_file))
        with open(full_file, 'w') as f:
            yaml.dump(manifest, f)



import os
import yaml


def read_target(target: str) -> any:
    real_target = os.path.abspath(target)
    manifests = {}
    if os.path.isfile(real_target):
        f = open(target, 'r')
        manifests = yaml.load_all(f)
    else:
        raise FileNotFoundError
    return manifests



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['splitem']

package_data = \
{'': ['*']}

install_requires = \
['PyYAML>=5.3.1,<6.0.0', 'click>=7.1.2,<8.0.0']

entry_points = \
{'console_scripts': ['splitem = splitem.cli:run']}

setup_kwargs = {
    'name': 'splitem',
    'version': '0.1.0',
    'description': 'Tool for splitting Kubernetes Manifests into individual files',
    'long_description': '',
    'author': 'Buck Brady',
    'author_email': 'buck@voidrot.dev',
    'maintainer': 'Buck Brady',
    'maintainer_email': 'buck@voidrot.dev',
    'url': 'https://github.com/voidrot/splitem',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
